/*
 * Scavenger_Beacon.c
 *
 * Created: 10/26/2011 9:40:09 PM
 *  Author: Kurt
 */ 

#define F_CPU 1200000UL // 9.6MHz/8 = 1.2MHz
#include <avr/io.h>
#include <avr/sleep.h>
#include <avr/interrupt.h>
#include <util/delay.h>
#include <avr/pgmspace.h>
#define CHECK_BIT(var,pos) ((var) & (1<<(pos)))
const int msecsDelayMark = 2;
const int msecsDelaySpace = 1;
int charactersSent=0;
int messageToSend=0;

const int lcdWidth=20;
const int lcdHeight=4;

//about 8 bytes/second.
const char flashMessage0[] PROGMEM = "Secret message follows... There are fresh cookies in the cookie jar!";
const char flashMessage1[] PROGMEM = "Why are you reading this? Cookies!";
const char flashMessage2[] PROGMEM = "Seriously? You're still here?";
const char flashMessage3[] PROGMEM = "OM NOM NOM!";
const char EOT = 4;
int main(void)
{
	DDRB |= 1<<DDB4;
	PORTB |= 1<<PB4;
	DDRB |= 1<<DDB3;
	PORTB |= 1<<PB3;
		
	/*
    while(1)
    {
		PORTB ^= 1<<PB4;
		_delay_ms (500);//10ms
    }
	*/
	//enable interrupts
	WDTCR |= (1<<WDP3) | (1<<WDP0);//8.0s
	WDTCR |= (1<<WDTIE);
	sei(); // Enable global interrupts 
	// Use the Power Down sleep mode
	set_sleep_mode(SLEEP_MODE_PWR_DOWN);
    while(1)
    {
		//TODO:: Please write your application code
		//sleep
		sleep_mode();   // go to sleep and wait for interrupt...
    }
}
void sendCharacter(int letter)
{
	int loop;
	letter &= 0xFF;//mask out anything over a byte
	letter |= 0x100;//tack on the start bit
	//transmit the MSB first
	//0, 1, MSB, 6 bits, LSB
	for (loop=9; loop>=0; loop--)
	{
		PORTB |= 1<<PB4;//turn the beam on
		PORTB |= 1<<PB3;//turn the beam on
		if (CHECK_BIT(letter, loop))
		{
			_delay_ms (msecsDelayMark);
		}
		else
		{
			_delay_ms (msecsDelaySpace);
		}
		PORTB &= (0xFF && 0<<PB4);//turn the beam off
		PORTB &= (0xFF && 0<<PB3);//turn the beam off
		_delay_ms (msecsDelaySpace);
	}
	_delay_ms (10);
	charactersSent++;
}
/*
void sendMessage(char message[])
{
	int loop=0;
	while (message[loop] != '\0')
	{
		sendCharacter(message[loop]);
		_delay_ms (msecsDelayMark);
		loop++;
	}
		sendCharacter(' ');
		_delay_ms (msecsDelayMark);
}
*/
void sendMessage(char message[])
{
	int i=0;
	for (i = 0; pgm_read_byte(&message[i]); i++) 
	{
		sendCharacter(pgm_read_byte(&message[i]));  
		//_delay_ms (msecsDelayMark);
	}
	sendCharacter(EOT);  
	/*
	while (charactersSent % (lcdWidth*lcdHeight) != 0)
	{
		sendCharacter(' ');
	}
	*/
	//_delay_ms (msecsDelayMark);
}
ISR(WDT_vect)
{
	if (messageToSend==0)
	{
		sendMessage(flashMessage0);
		messageToSend++;
	}
	else if (messageToSend==1)
	{
		sendMessage(flashMessage1);
		messageToSend++;
	}
	else if (messageToSend==2)
	{
		sendMessage(flashMessage2);
		messageToSend++;
	}
	else if (messageToSend==3)
	{
		sendMessage(flashMessage3);
		messageToSend=0;
	}
}